]> sigrok.org Git - libsigrok.git/blobdiff - device.c
Rename sr_dev_has_hwcap() to sr_dev_has_option().
[libsigrok.git] / device.c
index fc8477a1cec894a89a392c59403846c38e5ff2bd..b51af2ba5127dda17a5325b1ae5962427471696b 100644 (file)
--- a/device.c
+++ b/device.c
@@ -183,27 +183,27 @@ SR_API int sr_dev_trigger_set(const struct sr_dev_inst *sdi, int probenum,
  *            If the device's 'driver' field is NULL (virtual device), this
  *            function will always return FALSE (virtual devices don't have
  *            a hardware capabilities list).
* @param hwcap The capability that should be checked (whether it's supported
*              by the specified device).
  *
* @return TRUE if the device has the specified capability, FALSE otherwise.
*         FALSE is also returned upon invalid input parameters or other
  *         error conditions.
  */
-SR_API gboolean sr_dev_has_hwcap(const struct sr_dev_inst *sdi, int hwcap)
+SR_API gboolean sr_dev_has_option(const struct sr_dev_inst *sdi, int key)
 {
-       const int *hwcaps;
+       const int *devopts;
        int i;
 
        if (!sdi || !sdi->driver)
                return FALSE;
 
-       if (sdi->driver->info_get(SR_DI_HWCAPS,
-                       (const void **)&hwcaps, NULL) != SR_OK)
+       if (sdi->driver->config_list(SR_CONF_DEVICE_OPTIONS,
+                       (const void **)&devopts, NULL) != SR_OK)
                return FALSE;
 
-       for (i = 0; hwcaps[i]; i++) {
-               if (hwcaps[i] == hwcap)
+       for (i = 0; devopts[i]; i++) {
+               if (devopts[i] == key)
                        return TRUE;
        }
 
@@ -329,17 +329,17 @@ SR_PRIV void sr_serial_dev_inst_free(struct sr_serial_dev_inst *serial)
 
 }
 
-SR_API int sr_dev_config_set(const struct sr_dev_inst *sdi, int hwcap,
+SR_API int sr_config_set(const struct sr_dev_inst *sdi, int hwcap,
                const void *value)
 {
        int ret;
 
-       if (!sdi || !sdi->driver || !sdi->driver->dev_config_set) {
+       if (!sdi || !sdi->driver || !sdi->driver->config_set) {
                sr_err("Unable to set config option.");
                return SR_ERR;
        }
 
-       ret = sdi->driver->dev_config_set(sdi, hwcap, value);
+       ret = sdi->driver->config_set(hwcap, value, sdi);
 
        return ret;
 }
@@ -183,27 +183,27 @@ SR_API int sr_dev_trigger_set(const struct sr_dev_inst *sdi, int probenum,
  *            function will always return FALSE (virtual devices don't have
  *            a hardware capabilities list).
- * @param hwcap The capability that should be checked (whether it's supported
- *              by the specified device).
+ * @param option The option that should be checked for support on the
+ *            specified device.
  *
@@ -183,27 +183,27 @@ SR_API int sr_dev_trigger_set(const struct sr_dev_inst *sdi, int probenum,
  *
- * @return TRUE if the device has the specified capability, FALSE otherwise.
- *         FALSE is also returned upon invalid input parameters or other
+ * @return TRUE if the device has the specified option, FALSE otherwise.
+ *         FALSE is also returned on invalid input parameters or other
  *         error conditions.
  */